@@ -271,6 +271,12 @@ class SegmentationDataset:
         # check whether polygon data has been set and matches the names in the source imagery
         self.check_polygons()
 
+        # check whether the labels_path directory exists
+        if isdir(self.labels_path):
+            pass
+        else:
+            mkdir(self.labels_path)
+
         # loop through the shapefiles in the polygons directory
         for filename in self.data_names:
             fname = splitext(filename)[0]
