@@ -162,7 +162,8 @@ class VGG19Unet(SegmentationModel):
         self.n_filters = n_filters
         self.dropout_rate = dropout_rate
 
-    def compile_model(self, loss: tf.keras.losses.Loss = 'sparse_categorical_crossentropy',
+    def compile_model(self, loss: list = ['sparse_categorical_crossentropy'],
+                      loss_weights: list = [1.0],
                       learning_rate: float = 0.001,
                       rescale_factor: float = 1 / 255,
                       include_residual: bool = False,
@@ -174,6 +175,7 @@ class VGG19Unet(SegmentationModel):
 
         Args:
             loss: the loss function to use during training;
+            loss_weights: the weights to apply to each loss;
             learning_rate: the starting learning rate for the Adam optimizer;
             rescale_factor: the factor by which to rescale the input tensor;
             include_residual: incorporate a residual connection into each convolutional block;
@@ -303,6 +305,7 @@ class VGG19Unet(SegmentationModel):
 
         # compile the model
         model.compile(loss=loss,
+                      loss_weights=loss_weights,
                       optimizer=tf.keras.optimizers.Adam(learning_rate=learning_rate,
                                                          clipnorm=1.0))
 
@@ -325,7 +328,8 @@ class Unet(SegmentationModel):
         self.n_filters = n_filters
         self.dropout_rate = dropout_rate
 
-    def compile_model(self, loss: tf.keras.losses.Loss = 'sparse_categorical_crossentropy',
+    def compile_model(self, loss: list =['sparse_categorical_crossentropy'],
+                      loss_weights: list = [1.0],
                       learning_rate: float = 0.001,
                       rescale_factor: float = 1 / 255,
                       include_residual: bool = False,
@@ -336,6 +340,7 @@ class Unet(SegmentationModel):
 
         Args:
             loss: the loss function to use during training;
+            loss_weights: the weights to apply to each loss;
             learning_rate: the starting learning rate for the Adam optimizer;
             rescale_factor: the factor by which to rescale the input tensor;
             include_residual: include residual connections in each level;
@@ -434,7 +439,9 @@ class Unet(SegmentationModel):
         model = tf.keras.Model(inputs=inputs, outputs=outputs)
 
         # compile the model
-        model.compile(loss=loss, optimizer=tf.keras.optimizers.Adam(learning_rate=learning_rate,
-                                                                    clipnorm=1.0))
+        model.compile(loss=loss,
+                      loss_weights=loss_weights,
+                      optimizer=tf.keras.optimizers.Adam(learning_rate=learning_rate,
+                                                         clipnorm=1.0))
 
         self.model = model
